# Panda Shifu [![GitHub Repo stars](https://img.shields.io/github/stars/XiongPengNUS/PandaShifu)](https://github.com/XiongPengNUS/PandaShifu/stargazers)

---

[![PyPI - Version](https://img.shields.io/pypi/v/pandashifu)](https://pypi.org/project/pandashifu/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/pandashifu)](https://pypi.org/project/pandashifu/) [![GitHub commit activity](https://img.shields.io/github/commit-activity/m/XiongPengNUS/PandaShifu)](https://github.com/XiongPengNUS/PandaShifu/graphs/commit-activity) [![GitHub last commit](https://img.shields.io/github/last-commit/XiongPengNUS/PandaShifu)](https://github.com/XiongPengNUS/PandaShifu/graphs/commit-activity) ![GitHub closed issues](https://img.shields.io/github/issues-closed/XiongPengNUS/PandaShifu) ![GitHub issues](https://img.shields.io/github/issues-raw/XiongPengNUS/PandaShifu)

**```PandaShifu```** is an open-source Python package that provides friendly graphical user interfaces for descriptive and predictive analytics on a given dataset. Specifically, the package is capable of processing and visualizing the given dataset, and building pipelines for econometrical and machine learning models. The software is developed to facilitate the teaching of the following courses offered by NUS Business School:

- [**DAO2702/DAO2702X Programming for Business Analytics**](https://nusmods.com/courses/DAO2702/programming-for-business-analytics)
- [**BMK5202 Python Programming for Business Analytics**](https://nusmods.com/courses/BMK5202/python-programming-for-business-analytics)
- [**BMH5104 Artificial Intelligence for HR**](https://nusmods.com/courses/BMH5104/artificial-intelligence-for-hr)

### Installation

The **```PandaShifu```** package can be installed from the [PyPI](https://pypi.org/project/pandashifu/) platform via the command:

```
pip install pandashifu
```

### Author
The **```Panda Shifu```** package is developed and maintained by [Dr. Peng Xiong](https://discovery.nus.edu.sg/11338-peng-xiong), who is currently a senior lecturer at the NUS Business School.
